==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSeries = /*@__PURE__*/ (() => {
    class ScatterSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSeries.$;
            this.rq = new ScatterFrame();
            this.rs = new ScatterFrame();
            this.ro = new ScatterFrame();
        }
        get_c1() {
            return true;
        }
        bv() {
            return new ScatterSeriesView(this);
        }
        gl() {
            return 0.7;
        }
        pu() {
            if (this.pt == 0) {
                return 2;
            }
            return super.pu();
        }
        lo(a) {
            super.lo(a);
            this.ud = a;
        }
    }
    ScatterSeries.$t = /*@__PURE__*/ markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
})();
/**
 * @hidden
 */
export let ScatterSeriesView = /*@__PURE__*/ (() => {
    class ScatterSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.df = null;
            this.df = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.p0 = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.o0 = a;
            this.e.gm = 3;
            this.e.gn = 2;
            this.e.go = 2;
            this.e.e3 = false;
        }
    }
    ScatterSeriesView.$t = /*@__PURE__*/ markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
})();

==> igniteui-react-charts-16.16.1.tgz: package/esm2015/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSeries = /*@__PURE__*/ (() => {
    class ScatterSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSeries.$;
            this.r3 = new ScatterFrame();
            this.r5 = new ScatterFrame();
            this.r1 = new ScatterFrame();
        }
        get_c4() {
            return true;
        }
        bx() {
            return new ScatterSeriesView(this);
        }
        gv() {
            return 0.7;
        }
        p7() {
            if (this.p6 == 0) {
                return 2;
            }
            return super.p7();
        }
        lz(a) {
            super.lz(a);
            this.u2 = a;
        }
    }
    ScatterSeries.$t = /*@__PURE__*/ markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
})();
/**
 * @hidden
 */
export let ScatterSeriesView = /*@__PURE__*/ (() => {
    class ScatterSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.df = null;
            this.df = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.qd = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.pb = a;
            this.e.gw = 3;
            this.e.gx = 2;
            this.e.gy = 2;
            this.e.e7 = false;
        }
    }
    ScatterSeriesView.$t = /*@__PURE__*/ markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
})();
